@@ -406,6 +406,7 @@ pub fn insert_header(
     let header = header.header();
     let signed_header = SignedHeaderRef(header, signature);
     let header_type = header.header_type();
+    let header_type = header_type.as_sql();
     let header_seq = header.header_seq();
     let author = header.author().clone();
     let prev_hash = header.prev_header().cloned();
@@ -418,7 +419,7 @@ pub fn insert_header(
         Header::CreateLink(create_link) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
@@ -431,7 +432,7 @@ pub fn insert_header(
         Header::DeleteLink(delete_link) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
@@ -442,12 +443,12 @@ pub fn insert_header(
         Header::Create(create) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
                 "entry_hash": create.entry_hash,
-                "entry_type": create.entry_type,
+                "entry_type": create.entry_type.as_sql(),
                 "private_entry": private,
                 "blob": to_blob(&signed_header)?,
             })?;
@@ -455,7 +456,7 @@ pub fn insert_header(
         Header::Delete(delete) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
@@ -467,12 +468,12 @@ pub fn insert_header(
         Header::Update(update) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
                 "entry_hash": update.entry_hash,
-                "entry_type": update.entry_type,
+                "entry_type": update.entry_type.as_sql(),
                 "original_entry_hash": update.original_entry_address,
                 "original_header_hash": update.original_header_address,
                 "private_entry": private,
@@ -486,7 +487,7 @@ pub fn insert_header(
         | Header::CloseChain(_) => {
             sql_insert!(txn, Header, {
                 "hash": hash,
-                "type": header_type ,
+                "type": header_type,
                 "seq": header_seq,
                 "author": author,
                 "prev_hash": prev_hash,
