@@ -24,7 +24,7 @@ async fn can_handle_update_in_scratch() {
     let td = EntryTestData::new();
 
     // - Create an entry on main db.
-    insert_valid_integrated_op(&mut txn, td.update_store_entry_op.clone()).unwrap();
+    insert_valid_integrated_op(&mut txn, &td.update_store_entry_op).unwrap();
     let r = td
         .query
         .run(Txn::from(&txn))
