@@ -12,8 +12,8 @@ async fn link_queries_are_ordered_by_timestamp() {
         .unwrap();
 
     let td = LinkTestData::new();
-    insert_valid_integrated_op(&mut txn, td.create_link_op.clone()).unwrap();
-    insert_valid_integrated_op(&mut txn, td.later_create_link_op.clone()).unwrap();
+    insert_valid_integrated_op(&mut txn, &td.create_link_op).unwrap();
+    insert_valid_integrated_op(&mut txn, &td.later_create_link_op).unwrap();
     let links = td.tag_query.run(Txn::from(&txn)).unwrap();
     assert_eq!(links, vec![td.link.clone(), td.later_link.clone()]);
     let links = td.details_tag_query.run(Txn::from(&txn)).unwrap();
