@@ -15,6 +15,7 @@ use holochain_p2p::HolochainP2pDnaT;
 use holochain_sqlite::rusqlite::Transaction;
 use holochain_types::db::DbRead;
 use holochain_types::db::DbWrite;
+use holochain_types::db_cache::DhtDbQueryCache;
 use holochain_types::dht_op::produce_op_lights_from_elements;
 use holochain_types::dht_op::produce_op_lights_from_iter;
 use holochain_types::dht_op::DhtOp;
@@ -22,6 +23,7 @@ use holochain_types::dht_op::DhtOpLight;
 use holochain_types::dht_op::OpOrder;
 use holochain_types::dht_op::UniqueForm;
 use holochain_types::element::SignedHeaderHashedExt;
+use holochain_types::sql::AsSql;
 use holochain_zome_types::header;
 use holochain_zome_types::query::ChainQueryFilterRange;
 use holochain_zome_types::CapAccess;
@@ -38,6 +40,7 @@ use holochain_zome_types::GrantedFunction;
 use holochain_zome_types::Header;
 use holochain_zome_types::HeaderBuilder;
 use holochain_zome_types::HeaderBuilderCommon;
+use holochain_zome_types::HeaderExt;
 use holochain_zome_types::HeaderHashed;
 use holochain_zome_types::HeaderInner;
 use holochain_zome_types::MembraneProof;
@@ -67,6 +70,7 @@ pub struct SourceChain<AuthorDb = DbWrite<DbKindAuthored>, DhtDb = DbWrite<DbKin
     scratch: SyncScratch,
     vault: AuthorDb,
     dht_db: DhtDb,
+    dht_db_cache: DhtDbQueryCache,
     keystore: MetaLairClient,
     author: Arc<AgentPubKey>,
     persisted_seq: u32,
@@ -331,6 +335,7 @@ impl SourceChain {
                     let child_chain = Self::new(
                         self.vault.clone(),
                         self.dht_db.clone(),
+                        self.dht_db_cache.clone(),
                         keystore.clone(),
                         (*self.author).clone(),
                     )
@@ -362,8 +367,14 @@ impl SourceChain {
                 }
             }
             Ok(zomed_headers) => {
-                authored_ops_to_dht_db(network, ops_to_integrate, &self.vault, &self.dht_db)
-                    .await?;
+                authored_ops_to_dht_db(
+                    network,
+                    ops_to_integrate,
+                    &self.vault,
+                    &self.dht_db,
+                    &self.dht_db_cache,
+                )
+                .await?;
                 SourceChainResult::Ok(zomed_headers)
             }
             result => result,
@@ -379,6 +390,7 @@ where
     pub async fn new(
         vault: AuthorDb,
         dht_db: DhtDb,
+        dht_db_cache: DhtDbQueryCache,
         keystore: MetaLairClient,
         author: AgentPubKey,
     ) -> SourceChainResult<Self> {
@@ -394,6 +406,7 @@ where
             scratch,
             vault,
             dht_db,
+            dht_db_cache,
             keystore,
             author,
             persisted_seq,
@@ -410,6 +423,7 @@ where
     pub async fn raw_empty(
         vault: AuthorDb,
         dht_db: DhtDb,
+        dht_db_cache: DhtDbQueryCache,
         keystore: MetaLairClient,
         author: AgentPubKey,
     ) -> SourceChainResult<Self> {
@@ -432,6 +446,7 @@ where
             scratch,
             vault,
             dht_db,
+            dht_db_cache,
             keystore,
             author,
             persisted_seq,
@@ -720,8 +735,8 @@ where
                         .query_and_then(
                         named_params! {
                                 ":author": author.as_ref(),
-                                ":entry_type": query.entry_type,
-                                ":header_type": query.header_type,
+                                ":entry_type": query.entry_type.as_sql(),
+                                ":header_type": query.header_type.as_sql(),
                                 ":range_start": match query.sequence_range {
                                     ChainQueryFilterRange::HeaderSeqRange(start, _) => Some(start),
                                     _ => None,
@@ -855,7 +870,7 @@ fn build_ops_from_headers(
         let ops_inner = produce_op_lights_from_iter(vec![item].into_iter())?;
 
         // Break apart the SignedHeaderHashed.
-        let (header, sig) = shh.into_header_and_signature();
+        let (header, sig) = shh.into_inner();
         let (header, hash) = header.into_inner();
 
         // We need to take the header by value and put it back each loop.
@@ -908,6 +923,7 @@ async fn rebase_headers_on(
 pub async fn genesis(
     authored: DbWrite<DbKindAuthored>,
     dht_db: DbWrite<DbKindDht>,
+    dht_db_cache: &DhtDbQueryCache,
     keystore: MetaLairClient,
     dna_hash: DnaHash,
     agent_pubkey: AgentPubKey,
@@ -977,7 +993,8 @@ pub async fn genesis(
             SourceChainResult::Ok(ops_to_integrate)
         })
         .await?;
-    authored_ops_to_dht_db_without_check(ops_to_integrate, &authored, &dht_db).await?;
+    authored_ops_to_dht_db_without_check(ops_to_integrate, &authored, &dht_db, dht_db_cache)
+        .await?;
     Ok(())
 }
 
@@ -987,7 +1004,7 @@ pub fn put_raw(
     ops: Vec<DhtOpLight>,
     entry: Option<Entry>,
 ) -> StateMutationResult<Vec<DhtOpHash>> {
-    let (header, signature) = shh.into_header_and_signature();
+    let (header, signature) = shh.into_inner();
     let (header, hash) = header.into_inner();
     let mut header = Some(header);
     let mut hashes = Vec::with_capacity(ops.len());
@@ -1087,7 +1104,7 @@ async fn _put_db<H: HeaderInner, B: HeaderBuilder<H>>(
     let (header, entry) = element.into_inner();
     let entry = entry.into_option();
     let hash = header.as_hash().clone();
-    vault.conn()?.with_commit_sync(|txn| {
+    vault.conn()?.with_commit_sync(|txn: &mut Transaction| {
         let (new_head, new_seq, new_timestamp) = chain_head_db(txn, author.clone())?;
         if new_head != prev_header {
             let entries = match (entry, header.header().entry_hash()) {
@@ -1182,6 +1199,7 @@ impl From<SourceChain> for SourceChainRead {
         SourceChainRead {
             vault: chain.vault.into(),
             dht_db: chain.dht_db.into(),
+            dht_db_cache: chain.dht_db_cache,
             scratch: chain.scratch,
             keystore: chain.keystore,
             author: chain.author,
@@ -1216,10 +1234,12 @@ pub mod tests {
 
         let mut mock = MockHolochainP2pDnaT::new();
         mock.expect_authority_for_hash().returning(|_| Ok(false));
+        let dht_db_cache = DhtDbQueryCache::new(dht_db.to_db().into());
 
         source_chain::genesis(
             db.clone(),
             dht_db.to_db(),
+            &dht_db_cache,
             keystore.clone(),
             fake_dna_hash(1),
             alice.clone(),
@@ -1230,6 +1250,7 @@ pub mod tests {
         let chain_1 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1237,6 +1258,7 @@ pub mod tests {
         let chain_2 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1244,6 +1266,7 @@ pub mod tests {
         let chain_3 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1314,10 +1337,12 @@ pub mod tests {
 
         let mut mock = MockHolochainP2pDnaT::new();
         mock.expect_authority_for_hash().returning(|_| Ok(false));
+        let dht_db_cache = DhtDbQueryCache::new(dht_db.to_db().into());
 
         source_chain::genesis(
             db.clone(),
             dht_db.to_db(),
+            &dht_db_cache,
             keystore.clone(),
             fake_dna_hash(1),
             alice.clone(),
@@ -1329,6 +1354,7 @@ pub mod tests {
         let chain_1 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1336,6 +1362,7 @@ pub mod tests {
         let chain_2 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1343,6 +1370,7 @@ pub mod tests {
         let chain_3 = SourceChain::new(
             db.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             alice.clone(),
         )
@@ -1449,6 +1477,7 @@ pub mod tests {
     async fn test_get_cap_grant() -> SourceChainResult<()> {
         let test_db = test_authored_db();
         let dht_db = test_dht_db();
+        let dht_db_cache = DhtDbQueryCache::new(dht_db.to_db().into());
         let keystore = test_keystore();
         let db = test_db.to_db();
         let secret = Some(CapSecretFixturator::new(Unpredictable).next().unwrap());
@@ -1469,6 +1498,7 @@ pub mod tests {
         source_chain::genesis(
             db.clone(),
             dht_db.to_db(),
+            &dht_db_cache,
             keystore.clone(),
             fake_dna_hash(1),
             alice.clone(),
@@ -1478,9 +1508,14 @@ pub mod tests {
         .unwrap();
 
         {
-            let chain =
-                SourceChain::new(db.clone(), dht_db.to_db(), keystore.clone(), alice.clone())
-                    .await?;
+            let chain = SourceChain::new(
+                db.clone(),
+                dht_db.to_db(),
+                dht_db_cache.clone(),
+                keystore.clone(),
+                alice.clone(),
+            )
+            .await?;
             assert_eq!(
                 chain
                     .valid_cap_grant(function.clone(), alice.clone(), secret.clone())
@@ -1501,6 +1536,7 @@ pub mod tests {
             let chain = SourceChain::new(
                 db.clone().into(),
                 dht_db.to_db(),
+                dht_db_cache.clone(),
                 keystore.clone(),
                 alice.clone(),
             )
@@ -1526,9 +1562,14 @@ pub mod tests {
         };
 
         {
-            let chain =
-                SourceChain::new(db.clone(), dht_db.to_db(), keystore.clone(), alice.clone())
-                    .await?;
+            let chain = SourceChain::new(
+                db.clone(),
+                dht_db.to_db(),
+                dht_db_cache.clone(),
+                keystore.clone(),
+                alice.clone(),
+            )
+            .await?;
             // alice should find her own authorship with higher priority than the committed grant
             // even if she passes in the secret
             assert_eq!(
@@ -1559,6 +1600,7 @@ pub mod tests {
             let chain = SourceChain::new(
                 db.clone().into(),
                 dht_db.to_db(),
+                dht_db_cache.clone(),
                 keystore.clone(),
                 alice.clone(),
             )
@@ -1586,9 +1628,14 @@ pub mod tests {
         };
 
         {
-            let chain =
-                SourceChain::new(db.clone(), dht_db.to_db(), keystore.clone(), alice.clone())
-                    .await?;
+            let chain = SourceChain::new(
+                db.clone(),
+                dht_db.to_db(),
+                dht_db_cache.clone(),
+                keystore.clone(),
+                alice.clone(),
+            )
+            .await?;
             // alice should find her own authorship with higher priority than the committed grant
             // even if she passes in the secret
             assert_eq!(
@@ -1623,6 +1670,7 @@ pub mod tests {
             let chain = SourceChain::new(
                 db.clone().into(),
                 dht_db.to_db(),
+                dht_db_cache.clone(),
                 keystore.clone(),
                 alice.clone(),
             )
@@ -1644,9 +1692,14 @@ pub mod tests {
         }
 
         {
-            let chain =
-                SourceChain::new(db.clone(), dht_db.to_db(), keystore.clone(), alice.clone())
-                    .await?;
+            let chain = SourceChain::new(
+                db.clone(),
+                dht_db.to_db(),
+                dht_db_cache.clone(),
+                keystore.clone(),
+                alice.clone(),
+            )
+            .await?;
             // alice should find her own authorship
             assert_eq!(
                 chain
@@ -1727,6 +1780,7 @@ pub mod tests {
         observability::test_run().ok();
         let test_db = test_authored_db();
         let dht_db = test_dht_db();
+        let dht_db_cache = DhtDbQueryCache::new(dht_db.to_db().into());
         let keystore = test_keystore();
         let vault = test_db.to_db();
         let mut mock = MockHolochainP2pDnaT::new();
@@ -1744,6 +1798,7 @@ pub mod tests {
         genesis(
             vault.clone().into(),
             dht_db.to_db(),
+            &dht_db_cache,
             keystore.clone(),
             fixt!(DnaHash),
             (*author).clone(),
@@ -1755,6 +1810,7 @@ pub mod tests {
         let source_chain = SourceChain::new(
             vault.clone().into(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             (*author).clone(),
         )
@@ -1805,6 +1861,7 @@ pub mod tests {
         let source_chain = SourceChain::new(
             vault.clone(),
             dht_db.to_db(),
+            dht_db_cache.clone(),
             keystore.clone(),
             (*author).clone(),
         )
@@ -1822,12 +1879,14 @@ pub mod tests {
     async fn source_chain_buffer_dump_entries_json() -> SourceChainResult<()> {
         let test_db = test_authored_db();
         let dht_db = test_dht_db();
+        let dht_db_cache = DhtDbQueryCache::new(dht_db.to_db().into());
         let keystore = test_keystore();
         let vault = test_db.to_db();
         let author = keystore.new_sign_keypair_random().await.unwrap();
         genesis(
             vault.clone().into(),
             dht_db.to_db(),
+            &dht_db_cache,
             keystore.clone(),
             fixt!(DnaHash),
             author.clone(),
